==> nextcloud-22.2.1.tgz: nextcloud/apps/activity/l10n/mn.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "Хуулав!",
    "Not supported!" : "Дэмжихгүй!",
    "Press ⌘-C to copy." : "Хуулахын тулд ⌘-C дарна уу.",
    "Press Ctrl-C to copy." : "Хуулахын тулд Ctrl-C дарна уу.",
    "{name} (invisible)" : "{name} (үл харагдах)",
    "{name} (restricted)" : "{name} (хязгаартай)",
    "Home" : "Нүүр",
    "in {path}" : "{path} -д",
    "This stream will show events like additions, changes & shares" : "Файл нэмэх, өөрчлөх болон түгээх гэх мэт үйл явдлууд энд харагдана",
    "There are no events for this filter" : "Энд ямар нэг үйл явдал алга",
    "Today" : "Өнөөдөр",
    "Yesterday" : "Өчигдөр",
    "Your feed URL is invalid" : "Таны URL хүчин төгөлдөр бус байна",
    "Your settings have been updated." : "Таны тохиргоог шинэчлэв",
    "Settings have been updated." : "Тохиргоог шинэчлэв",
    "All activities" : "Бүх үйлдэлүүд",
    "By others" : "Бусдын үйлдлүүд",
    "By you" : "Таны үйлдлүүд",
    "Hello %s" : "Сайн байна уу, %s",
    "Hello %s," : "Сайн байна уу, %s,",
    "Mail" : "Цахим шуудан",
    "Activity" : "Үйлдлүүд",
    "Notifications" : "Мэдэгдэл",
    "No activity yet" : "Одоохондоо ямар ч үйлдэл алга",
    "Activity feed" : "Үйлдлүүдйн тэжээл",
    "Enable notification emails" : "Эмэйл мэдэгдлийг идэвхжүүлэх",
    "Default settings" : "Өгөгдмөл тохиргоо",
    "You need to set up your email address before you can receive notification emails." : "Та цахим шуудангаар мэдэгдэл хүлээн авахын тулд цахим шуудангаа тохируулна уу?",
    "Hourly" : "Цаг бүр",
    "Daily" : "Өдөр бүр",
    "Weekly" : "Долоо хоног бүр",
    "Settings" : "Тохиргоо",
    "Enable RSS feed" : "RSS feed идэвхжүүлэх",
    "An error occurred while loading activities" : "Үйлдлүүдийг ачааллахад алдаа гарлаа",
    "Load more activities" : "Бусад үйлдлүүдийг ачаалах",
    "Open file" : "Файл онгойлгох",
    "Send notification emails:" : "Эмэйлээр мэдэгдэл авах "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.10.tgz: nextcloud/apps/activity/l10n/mn.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "Хуулав!",
    "Not supported!" : "Дэмжихгүй!",
    "Press ⌘-C to copy." : "Хуулахын тулд ⌘-C дарна уу.",
    "Press Ctrl-C to copy." : "Хуулахын тулд Ctrl-C дарна уу.",
    "{name} (invisible)" : "{name} (үл харагдах)",
    "{name} (restricted)" : "{name} (хязгаартай)",
    "Home" : "Нүүр",
    "in {path}" : "{path} -д",
    "This stream will show events like additions, changes & shares" : "Файл нэмэх, өөрчлөх болон түгээх гэх мэт үйл явдлууд энд харагдана",
    "There are no events for this filter" : "Энд ямар нэг үйл явдал алга",
    "Today" : "Өнөөдөр",
    "Yesterday" : "Өчигдөр",
    "Your feed URL is invalid" : "Таны URL хүчин төгөлдөр бус байна",
    "Your settings have been updated." : "Таны тохиргоог шинэчлэв",
    "Settings have been updated." : "Тохиргоог шинэчлэв",
    "All activities" : "Бүх үйлдэлүүд",
    "By others" : "Бусдын үйлдлүүд",
    "By you" : "Таны үйлдлүүд",
    "Hello %s" : "Сайн байна уу, %s",
    "Hello %s," : "Сайн байна уу, %s,",
    "Mail" : "Цахим шуудан",
    "Activity" : "Үйлдлүүд",
    "Notifications" : "Мэдэгдэл",
    "No activity yet" : "Одоохондоо ямар ч үйлдэл алга",
    "Activities" : "Үйлдлүүд",
    "No activities" : "Үйлдэл алга",
    "Activity feed" : "Үйлдлүүдийн тэжээл",
    "Enable notification emails" : "Имэйл мэдэгдлийг идэвхжүүлэх",
    "Default settings" : "Өгөгдмөл тохиргоо",
    "You need to set up your email address before you can receive notification emails." : "Та Имэйлээр мэдэгдэл хүлээн авахын тулд имэйлээ тохируулна уу?",
    "Hourly" : "Цаг бүр",
    "Daily" : "Өдөр бүр",
    "Weekly" : "Долоо хоног бүр",
    "Settings" : "Тохиргоо",
    "Enable RSS feed" : "RSS feed идэвхжүүлэх",
    "Send notification emails:" : "Имэйлээр мэдэгдэл авах "
},
"nplurals=2; plural=(n != 1);");
